unit DebugFrm;

interface

uses
  Windows, Messages, SysUtils, Classes, Graphics, Controls, Forms, Dialogs,
  StdCtrls, ExtCtrls, ListenerModule, CHMnet, CHM;

type
  TDebugForm = class(TForm)
    memOutput: TMemo;
    pnlControls: TPanel;
    btnClose: TButton;
    AutoAckEngine: TCHMdynamicEngine;
    Listener: TCHMllpServer;
    procedure FormCreate(Sender: TObject);
    procedure FormDestroy(Sender: TObject);
    procedure btnCloseClick(Sender: TObject);
    procedure ListenerClientConnected(Sender: TObject;
      Client: ICHMllpConnection);
    procedure ListenerClientDisconnected(Sender: TObject;
      Client: ICHMllpConnection);
    procedure ListenerClientErrorReceived(Sender: TObject;
      Client: ICHMllpConnection; ErrorMessage: String; ErrorCode: Integer);
    procedure ListenerDataIgnored(Sender: TObject;
      Client: ICHMllpConnection; Data: String);
    procedure ListenerErrorReceived(Sender: TObject; ErrorMessage: String;
      Code: Integer);
    procedure ListenerMessageReceived(Sender: TObject;
      Client: ICHMllpConnection; Message: String);
  private
    { Private declarations }
    FListenerModule : TListenerModule;
    procedure Log(Line: String);
  public
    { Public declarations }
  end;

var
  DebugForm: TDebugForm;

implementation

{$R *.DFM}

procedure TDebugForm.FormCreate(Sender: TObject);
begin
  FListenerModule := TListenerModule.Create(AutoAckEngine, Listener);
  FListenerModule.OnLog := Log;
  FListenerModule.Start();
end;

procedure TDebugForm.FormDestroy(Sender: TObject);
begin
  FListenerModule.Stop();
end;

procedure TDebugForm.ListenerClientConnected(Sender: TObject;
  Client: ICHMllpConnection);
begin
  FListenerModule.HandleClientConnected(Client);
end;

procedure TDebugForm.ListenerClientDisconnected(Sender: TObject;
  Client: ICHMllpConnection);
begin
  FListenerModule.HandleClientDisconnected(Client);
end;

procedure TDebugForm.ListenerClientErrorReceived(Sender: TObject;
  Client: ICHMllpConnection; ErrorMessage: String; ErrorCode: Integer);
begin
  FListenerModule.HandleClientErrorReceived(Client, ErrorMessage, ErrorCode);
end;

procedure TDebugForm.ListenerDataIgnored(Sender: TObject;
  Client: ICHMllpConnection; Data: String);
begin
  FListenerModule.HandleDataIgnored(Client, Data);
end;

procedure TDebugForm.ListenerErrorReceived(Sender: TObject;
  ErrorMessage: String; Code: Integer);
begin
  FListenerModule.HandleErrorReceived(ErrorMessage, Code);
end;

procedure TDebugForm.ListenerMessageReceived(Sender: TObject;
  Client: ICHMllpConnection; Message: String);
begin
  FListenerModule.HandleMessageReceived(Client, Message);
end;

procedure TDebugForm.btnCloseClick(Sender: TObject);
begin
  DebugForm.Close;
end;

procedure TDebugForm.Log(Line: String);
begin
   memOutput.Lines.BeginUpdate;
   if (memOutput.Lines.Count > 3000) then
   begin
      memOutput.Lines.Clear;
   end;
   memOutput.Lines.EndUpdate;
   memOutput.Lines.Add(Line);
end;

end.

