unit ListenerServ;

interface

uses
  Windows, Messages, SysUtils, Classes, Graphics, Controls, SvcMgr, Dialogs,
  Forms, CHMnet, ListenerModule, CHM;

type
  TServerService = class(TService)
    Listener: TCHMllpServer;
    AutoAckEngine: TCHMdynamicEngine;
    procedure ServerServiceExecute(Sender: TService);
    procedure ListenerClientConnected(Sender: TObject;
      Client: ICHMllpConnection);
    procedure ListenerClientDisconnected(Sender: TObject;
      Client: ICHMllpConnection);
    procedure ListenerClientErrorReceived(Sender: TObject;
      Client: ICHMllpConnection; ErrorMessage: String; ErrorCode: Integer);
    procedure ListenerDataIgnored(Sender: TObject; Client: ICHMllpConnection;
      Data: String);
    procedure ListenerErrorReceived(Sender: TObject; ErrorMessage: String;
      Code: Integer);
    procedure ListenerMessageReceived(Sender: TObject;
      Client: ICHMllpConnection; Message: String);
  private
    { Private declarations }
    FListenerModule: TListenerModule;
    LogFile: TextFile;
    procedure Log(Line: string);
  public
    function GetServiceController: PServiceController; override;
    { Public declarations }
  end;

const
  APP_LOG_FILE = 'hl7log.txt';

var
  ServerService: TServerService;

implementation

{$R *.DFM}

procedure ServiceController(CtrlCode: DWord); stdcall;
begin
  ServerService.Controller(CtrlCode);
end;

function TServerService.GetServiceController: PServiceController;
begin
  Result := @ServiceController;
end;

procedure TServerService.ServerServiceExecute(Sender: TService);
begin
  AssignFile(LogFile, ExtractFileDir(Application.ExeName) + '\' + APP_LOG_FILE);

  try
    Append(LogFile);
  except
    Rewrite(LogFile);
  end;

  FListenerModule := TListenerModule.Create(AutoAckEngine, Listener);
  FListenerModule.OnLog := Log;
  FListenerModule.Start();

  // Wait for termination.
  while not Terminated do
    ServiceThread.ProcessRequests(True);

  FListenerModule.Stop();
  CloseFile(LogFile);
end;

procedure TServerService.ListenerClientConnected(Sender: TObject;
  Client: ICHMllpConnection);
begin
  FListenerModule.HandleClientConnected(Client);
end;

procedure TServerService.ListenerClientDisconnected(Sender: TObject;
  Client: ICHMllpConnection);
begin
  FListenerModule.HandleClientDisconnected(Client);
end;

procedure TServerService.ListenerClientErrorReceived(Sender: TObject;
  Client: ICHMllpConnection; ErrorMessage: String; ErrorCode: Integer);
begin
  FListenerModule.HandleClientErrorReceived(Client, ErrorMessage, ErrorCode);
end;

procedure TServerService.ListenerDataIgnored(Sender: TObject;
  Client: ICHMllpConnection; Data: String);
begin
  FListenerModule.HandleDataIgnored(Client, Data);
end;

procedure TServerService.ListenerErrorReceived(Sender: TObject;
  ErrorMessage: String; Code: Integer);
begin
  FListenerModule.HandleErrorReceived(ErrorMessage, Code);
end;

procedure TServerService.ListenerMessageReceived(Sender: TObject;
  Client: ICHMllpConnection; Message: String);
begin
  FListenerModule.HandleMessageReceived(Client, Message);
end;

procedure TServerService.Log(Line: string);
begin
  // TODO Some type of Log Purging will be required in a real application.
  Line := FormatDateTime('mmmm dd, yyyy hh:nn:ss', Now) + ' ' + Line;
  Writeln(LogFile, Line);
  Flush(LogFile);
end;

end.

